.. _whatsnew:

**********************
"What's new" documents
**********************

These document the changes between minor (or major) versions of h5py.

.. toctree::

    2.4
    2.3
    2.2
    2.1
    2.0
